@@ -200,7 +200,7 @@ class Slack:
 
     def get_user_info(self, user, include_locale=False):
         """Return info about a user."""
-        return self.webclient.users_info(include_locale=include_locale).get("user")
+        return self.webclient.users_info(user=user, include_locale=include_locale).get("user")
 
     def get_users(self, include_locale=False):
         """Return a list of Slack users."""
@@ -209,13 +209,17 @@ class Slack:
         # get first page of results
         response = self.webclient.users_list(include_locale=include_locale)
         users.extend(response["members"])
-        cursor = response["response_metadata"]["next_cursor"]
+        cursor = None
+        if response["response_metadata"]:
+            cursor = response["response_metadata"]["next_cursor"]
 
         # get additional pages
         while cursor:
             response = self.webclient.users_list(include_locale=include_locale, cursor=cursor)
             users.extend(response["members"])
-            cursor = response["response_metadata"]["next_cursor"]
+            cursor = None
+            if response["response_metadata"]:
+                cursor = response["response_metadata"]["next_cursor"]
 
         return users
 
