@@ -63,8 +63,8 @@ class Update:
 
         # get person
         person = self.people[email]
-        person_first_name = person["first_name"]
-        person_last_name = person["last_name"]
+        person_first_name = person["first_name_ascii"]
+        person_last_name = person["last_name_ascii"]
         person_phone = person.get("primary_work_phone")
         person_title = person["title"]
 
